@@ -18,10 +18,18 @@ sub run { confess 'Method "run" not implemented by subclass' }
 
 1;
 
+=encoding utf8
+
 =head1 NAME
 
 Giblog::Command - command base class
 
+=head1 DESCRIPTION
+
+L<Giblog::Command> is command base class.
+
+You can also create your command inheriting L<Giblog::Command> like L<Giblog::Command::new>, L<Giblog::Command::add> or L<Giblog::Command::build>.
+
 =head1 METHODS
 
 =head2 new
@@ -30,6 +38,16 @@ Giblog::Command - command base class
 
 Create command object.
 
+Arguments:
+
+=over 2
+
+=item * api
+
+L<Giblog::API> object.
+
+=back
+
 =head2 api
 
   $command->api;
@@ -40,4 +58,4 @@ Get L<Giblog::API> object.
 
   $command->run(@args);
 
-Run command. This method is implemented by subclass
+Run command. This method is implemented by subclass.
